"""This module is for the translation mapping data of the
following document:

Document file: graphics_draw_circle.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics draw_circle interface": "# Graphics クラスの draw_circle インターフェイス",
    ##################################################
    "This page explains the `Graphics` class `draw_circle` method interface.": "このページでは`Graphics`クラスの`draw_circle`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "`draw_circle` interface draws the vector circle graphics.": "`draw_circle`インターフェイスはベクターグラフィックスの円を描画します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `draw_circle` interface has the `x`\\, `y`\\, and `radius` arguments.": "`draw_circle`インターフェイスは`x`と`y`、そして`radius`引数を持っています。",  # noqa
    ##################################################
    "The `x` and `y` arguments are the circle center coordinates, and the `radius` argument determines the circle size. The width and height become twice the `radius` value.": "`x`と`y`引数は円の中央座標となります。`radius`引数は円の半径となります、幅と高さは`radius`引数の2倍の値になります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=200, stage_elem_id="stage"\n)\n\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the cyan color and draw the circle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_circle(x=100, y=100, radius=50)\n\n# Set the dotted-line style and draw the circle.\nsprite.graphics.begin_fill(color="")\nsprite.graphics.line_style(\n    color="#fff", thickness=3, dot_setting=ap.LineDotSetting(dot_size=3)\n)\nsprite.graphics.draw_circle(x=250, y=100, radius=50)\n\n# Draw the inner circle.\nsprite.graphics.draw_circle(x=250, y=100, radius=25)\n\nap.save_overall_html(dest_dir_path="graphics_draw_circle_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=200, stage_elem_id="stage"\n)\n\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the cyan color and draw the circle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_circle(x=100, y=100, radius=50)\n\n# Set the dotted-line style and draw the circle.\nsprite.graphics.begin_fill(color="")\nsprite.graphics.line_style(\n    color="#fff", thickness=3, dot_setting=ap.LineDotSetting(dot_size=3)\n)\nsprite.graphics.draw_circle(x=250, y=100, radius=50)\n\n# Draw the inner circle.\nsprite.graphics.draw_circle(x=250, y=100, radius=25)\n\nap.save_overall_html(dest_dir_path="graphics_draw_circle_basic_usage/")\n```',  # noqa
    ##################################################
    "## Return value": "## 返却値",
    ##################################################
    "The return value of the `draw_circle` interface is the instance of the `Circle` class.": "`draw_circle`インターフェイスの返却値は`Circle`クラスのインスタンスとなります。",  # noqa
    ##################################################
    "It has the `radius` attribute or other basic interfaces and you can change these settings.": "このインスタンスは`radius`属性や他の基本的な各インターフェイスを持っており生成後に値を更新することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=400, stage_height=400, stage_elem_id="stage"\n)\n\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw the small radius circle.\nsprite.graphics.begin_fill(color="#0af")\ncircle: ap.Circle = sprite.graphics.draw_circle(x=200, y=200, radius=25)\n\n# Update circle radius to become the bigger one.\ncircle.radius = ap.Int(100)\n\nap.save_overall_html(dest_dir_path="graphics_draw_circle_return_value/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=400, stage_height=400, stage_elem_id="stage"\n)\n\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw the small radius circle.\nsprite.graphics.begin_fill(color="#0af")\ncircle: ap.Circle = sprite.graphics.draw_circle(x=200, y=200, radius=25)\n\n# Update circle radius to become the bigger one.\ncircle.radius = ap.Int(100)\n\nap.save_overall_html(dest_dir_path="graphics_draw_circle_return_value/")\n```',  # noqa
    ##################################################
    "## draw_circle API": "## draw_circle API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Draw a circle vector graphics.<hr>": "円のベクターグラフィックスを描画します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x`: Int or int": "- `x`: Int or int",
    ##################################################
    "  - X-coordinate of the circle center.": "  - 円の中心のX座標。",
    ##################################################
    "- `y`: Int or int": "- `y`: Int or int",
    ##################################################
    "  - Y-coordinate of the circle center.": "  - 円の中心のY座標。",
    ##################################################
    "- `radius`: Int or int": "- `radius`: Int or int",
    ##################################################
    "  - Circle radius.": "  - 円の半径。",
    ##################################################
    "- `variable_name_suffix`: str, default ''": "- `variable_name_suffix`: str, default ''",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript's debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `circle`: Circle": "- `circle`: Circle",
    ##################################################
    "  - Created circle graphics instance.": "  - 生成された円のグラフィックスのインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> circle: ap.Circle = sprite.graphics.draw_circle(x=100, y=100, radius=50)\n>>> circle.x\nInt(100)\n\n>>> circle.y\nInt(100)\n\n>>> circle.radius\nInt(50)\n\n>>> circle.fill_color\nString('#00aaff')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> circle: ap.Circle = sprite.graphics.draw_circle(x=100, y=100, radius=50)\n>>> circle.x\nInt(100)\n\n>>> circle.y\nInt(100)\n\n>>> circle.radius\nInt(50)\n\n>>> circle.fill_color\nString('#00aaff')\n```",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: display_on_colaboratory.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# display_on_colaboratory interface": "# display_on_colaboratory インターフェイス",
    ##################################################
    "This page will explain the `display_on_colaboratory` function interface.": "このページでは`display_on_colaboratory`関数のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `display_on_colaboratory` interface displays the apysc HTML on the Google Colaboratory.": "`display_on_colaboratory`インターフェイスはapyscのHTMLをGoogle Colaboratory上で表示します。",  # noqa
    ##################################################
    "## Requirements": "## 必要とされるインストールなどの対応",
    ##################################################
    "You need to install apysc on the Google Colaboratory before going on. The `!` symbol and pip command on the Google Colaboratory installs this library:": "利用するには事前にGoogle Colaboratory上でapyscをインストールする必要があります。`!`の記号とpip五万度でGoogle Colaboratory上にこのライブラリをインストールすることができます。",  # noqa
    ##################################################
    "```\n!pip install apysc\n```": "```\n!pip install apysc\n```",
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "You can use the `display_on_colaboratory` interface to display an output HTML instead of the `save_overall_html` function.": "`save_overall_html`関数の代わりに`display_on_colaboratory`関数のインターフェイスを使うことで出力結果のHTMLを表示することができます。",  # noqa
    ##################################################
    "This interface requires the `html_file_name` argument to be unique if you need to output multiple HTML. Otherwise, it overwrites the HTML file:": "このインターフェイスは複数の出力出力ファイルをユニークにするための`html_file_name`引数によるファイル名の指定が必要になります。ユニークに設定しないとHTMLファイルが上書きされてしまいます。",  # noqa
    ##################################################
    '```py\nimport apysc as ap\n\nap.Stage(stage_width=250, stage_height=150, background_color="#333")\nsprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.display_on_colaboratory(html_file_name="jupyter_test_1.html")\n```': '```py\nimport apysc as ap\n\nap.Stage(stage_width=250, stage_height=150, background_color="#333")\nsprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.display_on_colaboratory(html_file_name="jupyter_test_1.html")\n```',  # noqa
    ##################################################
    "![](_static/colaboratory_interface.png)": "![](_static/colaboratory_interface.png)",  # noqa
    ##################################################
    "## display_on_colaboratory API": "## display_on_colaboratory API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Save the overall HTML and display it on Google Colaboratory.<hr>": "HTML全体を保存し結果をGoogle Colaboratory上で表示します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `html_file_name`: str, default 'index.html'": "- `html_file_name`: str, default 'index.html'",  # noqa
    ##################################################
    "  - The output HTML file name.": "  - 出力されるHTMLのファイル名。",
    ##################################################
    "- `minify`: bool, default True": "- `minify`: bool, default True",
    ##################################################
    "  - Boolean value whether minify a HTML or not. False setting is useful when debugging.": "  - HTMLを最小化（minify）するかどうかの真偽値。Falseの設定はデバッグ時などに役に立つことがあります。",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: graphics_move_to_and_line_to.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics move_to and line_to interfaces": "# Graphics クラスの move_to と line_to インターフェイス",  # noqa
    ##################################################
    "This page explains the `Graphics` class `move_to` and `line_to` method interfaces.": "このページでは`Graphics`クラスの`move_to`と`line_to`メソッドの各インターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interfaces are they?": "## 各インターフェイスの概要",
    ##################################################
    "The `move_to` interface sets the line start point. The `line_to` draws the line from a current point to a destination point. Sequentially, if you call the `line_to` interface, the line becomes polyline.": "`move_to`インターフェイスは線の描画の開始位置を設定します。`line_to`インターフェイスは現在の位置から終点位置に向けて線を描画します。連続して`line_to`を呼び出すと対象の線は折れ線になります。",  # noqa
    ##################################################
    "If you call the `move_to` interface after the calling of `line_to`\\, it creates a new line instance.": "もしも`line_to`インターフェイスを呼んだ後に`move_to`インターフェイスを呼んだ場合には新しい線のインスタンスが生成されます。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `move_to` and `line_to` interfaces have x and y arguments.": "`move_to`と`line_to`インターフェイスは共にxとyの引数を必要とします。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=100, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# Move to x=50, y=50 point (no drawing).\nsprite.graphics.move_to(x=50, y=50)\n\n# Draw the line from the current point (50, 50) to the\n# destination point (250, 50).\nsprite.graphics.line_to(x=250, y=50)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=100, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# Move to x=50, y=50 point (no drawing).\nsprite.graphics.move_to(x=50, y=50)\n\n# Draw the line from the current point (50, 50) to the\n# destination point (250, 50).\nsprite.graphics.line_to(x=250, y=50)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_basic_usage/")\n```',  # noqa
    ##################################################
    "## Sequential calling of the line_to interface": "## line_to インターフェイスの連続した呼び出し",
    ##################################################
    "Sequentially, if you call the `line_to` interface, the result line becomes the polyline.": "`line_to`インターフェイスを連続して呼び出した場合、結果の線は折れ線になります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=200, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# Move to x=50, y=50 point (no drawing).\nsprite.graphics.move_to(x=50, y=50)\n\n# Draw the line from the current point (50, 50) to the\n# destination point (150, 50).\nsprite.graphics.line_to(x=150, y=50)\n\n# Draw the line from the current point (250, 50) to the\n# destination point (50, 150). This calling changes the line\n# to the polyline.\nsprite.graphics.line_to(x=50, y=150)\n\n# Finally the polyline becomes Z shape by drawing to\n# destination point (150, 150).\nsprite.graphics.line_to(x=150, y=150)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_sequential_calling/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=200, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# Move to x=50, y=50 point (no drawing).\nsprite.graphics.move_to(x=50, y=50)\n\n# Draw the line from the current point (50, 50) to the\n# destination point (150, 50).\nsprite.graphics.line_to(x=150, y=50)\n\n# Draw the line from the current point (250, 50) to the\n# destination point (50, 150). This calling changes the line\n# to the polyline.\nsprite.graphics.line_to(x=50, y=150)\n\n# Finally the polyline becomes Z shape by drawing to\n# destination point (150, 150).\nsprite.graphics.line_to(x=150, y=150)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_sequential_calling/")\n```',  # noqa
    ##################################################
    "## move_to interface calling after line_to interface calling": "## line_to インターフェイスを呼び出した後の move_to インターフェイスの呼び出し",  # noqa
    ##################################################
    "If you call the `move_to` interface after calling the `line_to` interface, it creates a new line instance.": "`line_to`インターフェイスを呼び出した後に`move_to`を呼び出した場合新しい線のインスタンスが生成されます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# First move_to interface calling.\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=100, y=50)\nsprite.graphics.line_to(x=50, y=100)\nsprite.graphics.line_to(x=100, y=100)\n\n# Second move_to interface calling. This will create a new\n# polyline instance.\nsprite.graphics.move_to(x=150, y=50)\nsprite.graphics.line_to(x=200, y=50)\nsprite.graphics.line_to(x=150, y=100)\nsprite.graphics.line_to(x=200, y=100)\n\nap.save_overall_html(\n    dest_dir_path="graphics_move_to_and_line_to_multi_move_to_calling/"\n)\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=5)\n\n# First move_to interface calling.\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=100, y=50)\nsprite.graphics.line_to(x=50, y=100)\nsprite.graphics.line_to(x=100, y=100)\n\n# Second move_to interface calling. This will create a new\n# polyline instance.\nsprite.graphics.move_to(x=150, y=50)\nsprite.graphics.line_to(x=200, y=50)\nsprite.graphics.line_to(x=150, y=100)\nsprite.graphics.line_to(x=200, y=100)\n\nap.save_overall_html(\n    dest_dir_path="graphics_move_to_and_line_to_multi_move_to_calling/"\n)\n```',  # noqa
    ##################################################
    "## Polyline instance": "## Polyline インスタンス",
    ##################################################
    "`move_to` and `line_to` interfaces will return `Polyline` instance. You can update each setting or bind events to that instance.": "`move_to`や`line_to`インターフェイスは`Polyline`クラスのインスタンスを返却します。そのインスタンスを使って各設定を更新したりイベントを設定したりすることができます。",  # noqa
    ##################################################
    "For instance, the following script sets the mouse event to `Polyline`\\, updates the line color, and sets dot style in the handler (`on_line_click`).": "例えば以下のコード例では`Polyline`のインスタンスにマウスイベントを設定し、`on_line_click`ハンドラ内で線の色の更新と点線のスタイルを設定しています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_line_click(e: ap.MouseEvent[ap.Polyline], options: dict) -> None:\n    """\n    The handler that the line instance calls when clicked.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        The event instance.\n    options : dict\n        Optional arguments.\n    """\n    polyline: ap.Polyline = e.this\n    polyline.line_color = ap.String("#f0a")\n    polyline.line_dot_setting = ap.LineDotSetting(dot_size=5)\n\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=100, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=30)\npolyline: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=150, y=50)\npolyline.click(on_line_click)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_polyline/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_line_click(e: ap.MouseEvent[ap.Polyline], options: dict) -> None:\n    """\n    The handler that the line instance calls when clicked.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        The event instance.\n    options : dict\n        Optional arguments.\n    """\n    polyline: ap.Polyline = e.this\n    polyline.line_color = ap.String("#f0a")\n    polyline.line_dot_setting = ap.LineDotSetting(dot_size=5)\n\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=100, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.line_style(color="#0af", thickness=30)\npolyline: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=150, y=50)\npolyline.click(on_line_click)\n\nap.save_overall_html(dest_dir_path="graphics_move_to_and_line_to_polyline/")\n```',  # noqa
    ##################################################
    "If you click the following line, line style will be updated:": "もし以下の四角をクリックし0た場合、線のスタイルは更新されます:",  # noqa
    ##################################################
    "## move_to API": "## move_to API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Move a line position to a specified point.<hr>": "指定された座標に線の描画位置を移動させます。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x`: Int or int": "- `x`: Int or int",
    ##################################################
    "  - X destination point to move.": "  - 移動先となるX座標。",
    ##################################################
    "- `y`: Int or int": "- `y`: Int or int",
    ##################################################
    "  - Y destination point to move.": "  - 移動先となるY座標。",
    ##################################################
    "- `variable_name_suffix`: str, default ''": "- `variable_name_suffix`: str, default ''",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript's debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line`: Polyline": "- `line`: Polyline",
    ##################################################
    "  - Line graphics instance.": "  - 線のグラフィックスのインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line_1: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\n>>> line_2: ap.Polyline = sprite.graphics.line_to(x=150, y=50)\n>>> line_1 == line_2\nTrue\n\n>>> line_1.line_color\nString('#ffffff')\n\n>>> line_1.line_thickness\nInt(5)\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line_1: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\n>>> line_2: ap.Polyline = sprite.graphics.line_to(x=150, y=50)\n>>> line_1 == line_2\nTrue\n\n>>> line_1.line_color\nString('#ffffff')\n\n>>> line_1.line_thickness\nInt(5)\n```",  # noqa
    ##################################################
    "## line_to API": "## line_to API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Draw a line from previous point to specified point (initial point is x = 0, y = 0).<hr>": "直前の位置の座標から指定された座標に向けて線を描画します（初期位置はx=0, y=0になります）。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x`: Int or int": "- `x`: Int or int",
    ##################################################
    "  - X destination point to draw a line.": "  - 線の描画先となる終点のX座標。",
    ##################################################
    "- `y`: Int or int": "- `y`: Int or int",
    ##################################################
    "  - Y destination point to draw a line.": "  - 線の描画先となる終点のY座標。",
    ##################################################
    "- `variable_name_suffix`: str, default ''": "- `variable_name_suffix`: str, default ''",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript's debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line`: Polyline": "- `line`: Polyline",
    ##################################################
    "  - Line graphics instance.": "  - 線のグラフィックスのインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line_1: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\n>>> line_2: ap.Polyline = sprite.graphics.line_to(x=150, y=50)\n>>> line_3: ap.Polyline = sprite.graphics.line_to(x=50, y=150)\n>>> line_1 == line_2 == line_3\nTrue\n\n>>> line_1.line_color\nString('#ffffff')\n\n>>> line_1.line_thickness\nInt(5)\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line_1: ap.Polyline = sprite.graphics.move_to(x=50, y=50)\n>>> line_2: ap.Polyline = sprite.graphics.line_to(x=150, y=50)\n>>> line_3: ap.Polyline = sprite.graphics.line_to(x=50, y=150)\n>>> line_1 == line_2 == line_3\nTrue\n\n>>> line_1.line_color\nString('#ffffff')\n\n>>> line_1.line_thickness\nInt(5)\n```",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: fundamental_data_classes_value_interface.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# apysc fundamental data classes value interface": "# apysc の基本的なデータ型の value インターフェイス。",  # noqa
    ##################################################
    "This page explains the apysc fundamental data classes (such as the `Int`\\, `Number`\\, `String`) `value` interface.": "このページではapyscの`Int`や`Number`、`String`などの基本的なデータクラスの`value`インターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `value` getter interface returns each data class value. And the setter interface updates these data class values.": "`value`のgetterのインターフェイスは各データクラスの値を返却します。setterのインターフェイスではそれらの値の更新を行います。",  # noqa
    ##################################################
    "A return value of the getter interface becomes a Python built-in value, like the `int`\\, `float`\\, `str`\\, `list`\\.": "返却値は基本的に`int`や`float`、`str`などのPythonビルトインの値になります。",  # noqa
    ##################################################
    "## Basic usage of the getter interface": "## getterのインターフェイスの基本的な使い方",
    ##################################################
    "The `value` getter interface returns the Python built-in value.": "`value`のgetterインターフェイスではPythonのビルトインの値を返却します。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nvalue = int_1.value\nassert isinstance(value, int)\n```": "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nvalue = int_1.value\nassert isinstance(value, int)\n```",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nnumber_1: ap.Number = ap.Number(10.5)\nvalue = number_1.value\nassert isinstance(value, float)\n```": "```py\n# runnable\nimport apysc as ap\n\nnumber_1: ap.Number = ap.Number(10.5)\nvalue = number_1.value\nassert isinstance(value, float)\n```",  # noqa
    ##################################################
    "## Basic usage of the setter interface": "## setterのインターフェイスの基本的な使い方",
    ##################################################
    "You can update the apysc fundamental data class values with the `value` setter interface. Python built-in values and the same type value is acceptable:": "apyscの基本的なデータクラスにおける`value`のsetterのインターフェイスではそれらの値を更新することができます。Pythonのビルトインの値やapyscの同じ型の値を指定することができます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nint_1.value = 20\nassert int_1 == 20\n```": "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nint_1.value = 20\nassert int_1 == 20\n```",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nint_1.value = ap.Int(20)\nassert int_1 == 20\n```": "```py\n# runnable\nimport apysc as ap\n\nint_1: ap.Int = ap.Int(10)\nint_1.value = ap.Int(20)\nassert int_1 == 20\n```",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: graphics_begin_fill.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics begin_fill interface": "# Graphics クラスの begin_fill インターフェイス",
    ##################################################
    "This page explains the `Graphics` class `begin_fill` method interface.": "このページでは`Graphics`クラスの`begin_fill`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "`begin_fill` interface would set the fill color and fill alpha settings. This setting would be maintained until it is called again or called the `clear` method.": "`begin_fill`インターフェイスは塗りの色と塗りの透明度を設定します。この設定は再度`begin_fill`のインターフェイスを呼び出すか、もしくは`clear`メソッドを呼ぶまで保持されます。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "Draw vector graphics interfaces (e.g., `draw_rect`) would use these fill settings when creating, so the `begin_fill` method needs to be called before calling each drawing interface.": "ベクターグラフィックスの描画系の各インターフェイス（例 : `draw_rect`など）はグラフィックス生成時にこの塗りの設定を参照します。そのため描画系のインターフェイスを実行する前にこの`begin_fill`のインターフェイスを呼び出しておく必要があります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set blue fill color and draw the first rectangle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Draw the second rectangle (fill color setting will be maintained).\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\n# Set the other fill color and draw the third rectangle.\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set blue fill color and draw the first rectangle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Draw the second rectangle (fill color setting will be maintained).\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\n# Set the other fill color and draw the third rectangle.\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_basic_usage/")\n```',  # noqa
    ##################################################
    "## Fill color setting": "## 塗りの色の設定",
    ##################################################
    "The `color` argument sets the fill color, and the `begin_fill` interface requires this argument.": "`color`引数は塗りの色を設定します。`begin_fill`インターフェイスではこの引数は必須になっています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan fill color and draw the rectangle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_fill_color/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan fill color and draw the rectangle.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_fill_color/")\n```',  # noqa
    ##################################################
    "If you want to clear fill color, specify a blank string to this argument.": "もしも塗りの色の設定を削除したい場合、空の文字列をこの引数に指定してください。",  # noqa
    ##################################################
    "For example, since the following code clears fill color settings, a rectangle graphic becomes invisible.": "以下のコード例では塗りの色の設定を削除しているため、四角のグラフィックは見えなくなります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.begin_fill(color="#0af")\n\n# Clear fill color by specifying blank string.\nsprite.graphics.begin_fill(color="")\n\n# Since fill color is not set, the rectangle is invisible.\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_color_setting_clear/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.begin_fill(color="#0af")\n\n# Clear fill color by specifying blank string.\nsprite.graphics.begin_fill(color="")\n\n# Since fill color is not set, the rectangle is invisible.\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_color_setting_clear/")\n```',  # noqa
    ##################################################
    "Color code is acceptable like the following list:": "カラーコードは以下の形の指定を受け付けています。",
    ##################################################
    "- Six characters, e.g., `#00aaff`.": "- `#00aaff`などの6文字による指定。",
    ##################################################
    "- Three characters, e.g., `#0af` (this becomes `#00aaff`).": "- `#0af`などの3文字による指定（これは`#00aaff`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Single character, e.g., `#5` (this becomes `#000005`).": "- `#5`などの1文字による指定（これは`000005`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Skipped `#` symbol, e.g., `0af` (this becomes `#00aaff`).": "- `0af`などの`#`記号を省略した指定（これは`#00aaff`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Blank string, e.g., `''` (this setting clears the fill color setting).": "- ``などの空文字（この指定は塗りの色の設定を削除します）。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=450, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Six characters fill color setting (a cyan color).\nsprite.graphics.begin_fill(color="#00aaff")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Three characters fill color setting (a magenta color).\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\n# Single characters fill color setting (a black color).\nsprite.graphics.begin_fill(color="#0")\nsprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\n\n# Fill color that Skipped `#` symbol is also acceptable.\nsprite.graphics.begin_fill(color="999")\nsprite.graphics.draw_rect(x=350, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_acceptable_color_settings/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=450, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Six characters fill color setting (a cyan color).\nsprite.graphics.begin_fill(color="#00aaff")\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Three characters fill color setting (a magenta color).\nsprite.graphics.begin_fill(color="#f0a")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\n# Single characters fill color setting (a black color).\nsprite.graphics.begin_fill(color="#0")\nsprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\n\n# Fill color that Skipped `#` symbol is also acceptable.\nsprite.graphics.begin_fill(color="999")\nsprite.graphics.draw_rect(x=350, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_acceptable_color_settings/")\n```',  # noqa
    ##################################################
    "## Fill color alpha (opacity) setting": "## 塗りの色の透明度の設定",
    ##################################################
    "Fill color alpha (opacity) can be set by the `alpha` argument. It can accept 0.0 (transparent) to 1.0 (opaque).": "塗りの透明度は`alpha`引数で設定できます。0.0（透明）～1.0（不透明）の範囲の値を受け付けます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=200, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.begin_fill(color="#00aaff", alpha=0.2)\nsprite.graphics.draw_rect(x=50, y=75, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=50, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=75, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=100, width=50, height=50)\nsprite.graphics.draw_rect(x=100, y=75, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_alpha_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=200, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\nsprite.graphics.begin_fill(color="#00aaff", alpha=0.2)\nsprite.graphics.draw_rect(x=50, y=75, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=50, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=75, width=50, height=50)\nsprite.graphics.draw_rect(x=75, y=100, width=50, height=50)\nsprite.graphics.draw_rect(x=100, y=75, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_begin_fill_alpha_setting/")\n```',  # noqa
    ##################################################
    "## begin_fill API": "## begin_fill API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Set single color value for fill.<hr>": "塗りのための単一の色の設定を行います。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `color`: str or String": "- `color`: str or String",
    ##################################################
    "  - Hexadecimal color string. e.g., '#00aaff'": "  - '#00aaff'などの16進数の色の文字列。",
    ##################################################
    "- `alpha`: float or Number, default 1.0": "- `alpha`: float or Number, default 1.0",  # noqa
    ##################################################
    "  - Color opacity (0.0 to 1.0).": "  - 塗りの透明度（0.0～1.0）。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_color\nString('#00aaff')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_color\nString('#00aaff')\n```",  # noqa
    ##################################################
    "## fill_color property API": "## fill_color 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current fill color.<hr>": "現在の塗りの色を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `fill_color`: String": "- `fill_color`: String",
    ##################################################
    "  - Current fill color (hexadecimal string, e.g., '#00aaff'). If not be set, this interface returns a blank string.": "  - 現在の塗りの色（`'#00aaff'`などの16進数の文字列）。もしも設定されていない場合空文字が返却されます。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_color\nString('#00aaff')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\"#0af\")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_color\nString('#00aaff')\n```",  # noqa
    ##################################################
    "## fill_alpha property API": "## fill_alpha 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current fill color opacity.<hr>": "現在の塗りの透明度を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `fill_alpha`: Number": "- `fill_alpha`: Number",
    ##################################################
    "  - Current fill color opacity (0.0 to 1.0). If not be set, 1.0 will be returned.": "  - 現在の塗りの透明度（0.0～1.0）。もし設定されていない場合1.0の値が返却されます。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_alpha\nNumber(0.5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_alpha\nNumber(0.5)\n```',  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: bind_and_trigger_custom_event.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Bind and trigger the custom event": "# カスタムイベントの登録とイベントの発生（発火）制御",
    ##################################################
    "This page explains the `bind_custom_event` and `trigger_custom_event` interfaces.": "このページでは`bind_custom_event`と`trigger_custom_event`の各インターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interfaces are these?": "## 各インターフェイスの概要",
    ##################################################
    "The `bind_custom_event` interface registers your custom event to the instance, and the `trigger_custom_event` one triggers the registered custom events at any time.": "`bind_custom_event`インターフェイスは対象のインスタンスに独自のイベントを登録し、`trigger_custom_event`インターフェイスは任意の箇所でカスタムイベントの発生（発火）の制御を行います。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `bind_custom_event` interface has the `custom_event_type`, `handler`, `e`, and `options` arguments (`options` is optional).": "`bind_custom_event`インターフェイスは`custom_event_type`と`handler`、`e`、そして`options`引数を持っています（`options`引数は省略可です）。",  # noqa
    ##################################################
    "The `custom_event_type` argument is the custom event type name's string. This value needs to specify the same one at the calling of the `trigger_custom_event` interface.": "`custom_event_type`引数は独自のイベントの種類の文字列です。この引数の文字列は`trigger_custom_event`インターフェイスでの指定時でも同じ値を設定する必要があります。",  # noqa
    ##################################################
    "The `e` argument is an event instance that may become the subclass of the `Event` class, such as the `MouseEvent` or `TimerEvent`\\.": "`e`引数はイベントのインスタンスです。場合によっては`MouseEvent`クラスや`TimerEvent`クラスなどの`Event`クラスのサブクラスを指定します。",  # noqa
    ##################################################
    "The following example rotates the rectangle when you click it. If the rectangle rotated 90 degrees, then the custom event (`rotate_90_degrees`) is triggered, and the `on_rotate_90_degrees` handler (custom event) is called and display the second rectangle (toggle the `visible` property):": "以下のコード例では四角をクリックした際に回転させるようにしています。もし回転量が90度に達した場合、`rotate_90_degrees`の独自のイベントが発生し`on_rotate_90_degrees`関数のハンドラが実行されます。対象のハンドラ内では2つ目の四角を`visible`属性を有効化する形で表示しています。",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n# Custom event type name.\nROTATE_90_DEGREES: str = "rotate_90_degrees"\n\n\nclass _RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_rectangle_click(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when clicked.\n\n    Parameters\n    ----------\n    e : ap.MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    e.this.unbind_click(on_rectangle_click)\n    options_: _RectOptions = {"rectangle": e.this}\n    timer: ap.Timer = ap.Timer(\n        on_timer, delay=ap.FPS.FPS_60, repeat_count=90, options=options_\n    )\n    timer.timer_complete(on_timer_complete, options=options_)\n    timer.start()\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.rotation_around_center += 1\n\n\ndef on_timer_complete(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that timer calls when its end.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.trigger_custom_event(custom_event_type=ROTATE_90_DEGREES)\n\n\ndef on_rotate_90_degrees(e: ap.Event, options: _RectOptions) -> None:\n    """\n    The handler that the rectangle rates 90 degrees (custom event).\n\n    Parameters\n    ----------\n    e : ap.Event\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.visible = ap.Boolean(True)\n\n\nap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_1.click(on_rectangle_click)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\nrectangle_2.visible = ap.Boolean(False)\n\ne: ap.Event = ap.Event(this=rectangle_1)\nrectangle_1.bind_custom_event(\n    custom_event_type=ROTATE_90_DEGREES,\n    handler=on_rotate_90_degrees,\n    e=e,\n    options={"rectangle": rectangle_2},\n)\n\nap.save_overall_html(dest_dir_path="bind_and_trigger_custom_event_basic_usage/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n# Custom event type name.\nROTATE_90_DEGREES: str = "rotate_90_degrees"\n\n\nclass _RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_rectangle_click(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when clicked.\n\n    Parameters\n    ----------\n    e : ap.MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    e.this.unbind_click(on_rectangle_click)\n    options_: _RectOptions = {"rectangle": e.this}\n    timer: ap.Timer = ap.Timer(\n        on_timer, delay=ap.FPS.FPS_60, repeat_count=90, options=options_\n    )\n    timer.timer_complete(on_timer_complete, options=options_)\n    timer.start()\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.rotation_around_center += 1\n\n\ndef on_timer_complete(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that timer calls when its end.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.trigger_custom_event(custom_event_type=ROTATE_90_DEGREES)\n\n\ndef on_rotate_90_degrees(e: ap.Event, options: _RectOptions) -> None:\n    """\n    The handler that the rectangle rates 90 degrees (custom event).\n\n    Parameters\n    ----------\n    e : ap.Event\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.visible = ap.Boolean(True)\n\n\nap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_1.click(on_rectangle_click)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\nrectangle_2.visible = ap.Boolean(False)\n\ne: ap.Event = ap.Event(this=rectangle_1)\nrectangle_1.bind_custom_event(\n    custom_event_type=ROTATE_90_DEGREES,\n    handler=on_rotate_90_degrees,\n    e=e,\n    options={"rectangle": rectangle_2},\n)\n\nap.save_overall_html(dest_dir_path="bind_and_trigger_custom_event_basic_usage/")\n```',  # noqa
    ##################################################
    "## bind_custom_event API": "## bind_custom_event API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Add a custom event listener setting.<hr>": "カスタムイベントのリスナー設定を追加します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `custom_event_type`: CustomEventType or str": "- `custom_event_type`: CustomEventType or str",  # noqa
    ##################################################
    "  - Target custom event type.": "  - 対象の独自のイベントの種別値としての文字列。",
    ##################################################
    "- `handler`: _Handler": "- `handler`: _Handler",
    ##################################################
    "  - Callable that this instance calls when its event's dispatching.": "  - 対象のイベントが発生（発火）される時に実行されるハンドラ。",  # noqa
    ##################################################
    "- `e`: Event": "- `e`: Event",
    ##################################################
    "  - Event instance.": "  - イベントのインスタンス。",
    ##################################################
    "- `options`: dict or None, default None": "- `options`: dict or None, default None",  # noqa
    ##################################################
    "  - Optional arguments dictionary to be passed to a handler.": "  - ハンドラに渡される省略が可能な追加のパラメーターとしての辞書。",  # noqa
    ##################################################
    "- `in_handler_head_expression`: str, default ''": "- `in_handler_head_expression`: str, default ''",  # noqa
    ##################################################
    "  - Optional expression to be added at the handler function's head position.": "  - 省略可能なハンドラ内の先頭に加える（JavaScriptの）表現の文字列。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `name`: str": "- `name`: str",
    ##################################################
    "  - Handler's name.": "  - ハンドラ名。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_custom_event(e: ap.Event[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.String("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> e: ap.Event = ap.Event(this=rectangle)\n>>> _ = rectangle.bind_custom_event(\n...     custom_event_type="my_custom_event", handler=on_custom_event, e=e\n... )\n>>> # Do something here and then trigger the custom event\n>>> rectangle.trigger_custom_event(custom_event_type="my_custom_event")\n```': '```py\n>>> import apysc as ap\n>>> def on_custom_event(e: ap.Event[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.String("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> e: ap.Event = ap.Event(this=rectangle)\n>>> _ = rectangle.bind_custom_event(\n...     custom_event_type="my_custom_event", handler=on_custom_event, e=e\n... )\n>>> # Do something here and then trigger the custom event\n>>> rectangle.trigger_custom_event(custom_event_type="my_custom_event")\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [About the handler options' type](https://simon-ritchie.github.io/apysc/en/about_handler_options_type.html)": "- [ハンドラのoptions引数の型について](https://simon-ritchie.github.io/apysc/jp/jp_about_handler_options_type.html)",  # noqa
    ##################################################
    "## trigger_custom_event API": "## trigger_custom_event API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Add a custom event trigger setting.<hr>": "カスタムイベントのトリガー設定を追加します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `custom_event_type`: CustomEventType or str": "- `custom_event_type`: CustomEventType or str",  # noqa
    ##################################################
    "  - Target custom event type.": "  - 対象の独自のイベントの種別値としての文字列。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_custom_event(e: ap.Event[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.String("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> e: ap.Event = ap.Event(this=rectangle)\n>>> _ = rectangle.bind_custom_event(\n...     custom_event_type="my_custom_event", handler=on_custom_event, e=e\n... )\n>>> # Do something here and then trigger the custom event\n>>> rectangle.trigger_custom_event(custom_event_type="my_custom_event")\n```': '```py\n>>> import apysc as ap\n>>> def on_custom_event(e: ap.Event[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.String("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> e: ap.Event = ap.Event(this=rectangle)\n>>> _ = rectangle.bind_custom_event(\n...     custom_event_type="my_custom_event", handler=on_custom_event, e=e\n... )\n>>> # Do something here and then trigger the custom event\n>>> rectangle.trigger_custom_event(custom_event_type="my_custom_event")\n```',  # noqa
}
